@@ -194,7 +194,7 @@ public:
     /** For expressing paragraph alignment. These values are rotated in the
     case of vertical text, but are not dependent on whether the paragraph is
     rtl or ltr, thus LEFT is always either left or top. */
-    enum Alignment {LEFT, CENTER, RIGHT, FULL};
+    enum Alignment {LEFT, CENTER, RIGHT, FULL, NONE};
 
     /** The CSS spec allows line-height:normal to be whatever the user agent
     thinks will look good. This is our value, as a multiple of font-size. */
@@ -1144,7 +1144,7 @@ inline unsigned Layout::paragraphIndex(iterator const &it) const
     {return it._char_index == _characters.size() ? _paragraphs.size() - 1 : _characters[it._char_index].line(this).in_paragraph;}
 
 inline Layout::Alignment Layout::paragraphAlignment(iterator const &it) const
-    {return _paragraphs[paragraphIndex(it)].alignment;}
+    {return (_paragraphs.size() == 0) ? NONE : _paragraphs[paragraphIndex(it)].alignment;}
 
 inline bool Layout::iterator::nextGlyph()
 {
